==> zio-aws-codebuild_3-5.17.104.12-sources.jar: zio/aws/codebuild/model/ListBuildsForProjectResponse.scala <==
package zio.aws.codebuild.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.codebuild.model.primitives.NonEmptyString
import scala.jdk.CollectionConverters.*
final case class ListBuildsForProjectResponse(
    ids: Option[Iterable[NonEmptyString]] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codebuild.model.ListBuildsForProjectResponse = {
    import ListBuildsForProjectResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codebuild.model.ListBuildsForProjectResponse
      .builder()
      .optionallyWith(
        ids.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.ids)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.codebuild.model.ListBuildsForProjectResponse.ReadOnly =
    zio.aws.codebuild.model.ListBuildsForProjectResponse.wrap(buildAwsValue())
}
object ListBuildsForProjectResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codebuild.model.ListBuildsForProjectResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codebuild.model.ListBuildsForProjectResponse =
      zio.aws.codebuild.model.ListBuildsForProjectResponse(
        ids.map(value => value),
        nextToken.map(value => value)
      )
    def ids: Option[List[NonEmptyString]]
    def nextToken: Option[String]
    def getIds: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("ids", ids)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codebuild.model.ListBuildsForProjectResponse
  ) extends zio.aws.codebuild.model.ListBuildsForProjectResponse.ReadOnly {
    override val ids: Option[List[NonEmptyString]] = scala
      .Option(impl.ids())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codebuild.model.primitives.NonEmptyString(item)
        }.toList
      )
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.codebuild.model.ListBuildsForProjectResponse
  ): zio.aws.codebuild.model.ListBuildsForProjectResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codebuild_3-5.17.269.1-sources.jar: zio/aws/codebuild/model/ListBuildsForProjectResponse.scala <==
package zio.aws.codebuild.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.codebuild.model.primitives.NonEmptyString
import scala.jdk.CollectionConverters.*
final case class ListBuildsForProjectResponse(
    ids: Optional[Iterable[NonEmptyString]] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codebuild.model.ListBuildsForProjectResponse = {
    import ListBuildsForProjectResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codebuild.model.ListBuildsForProjectResponse
      .builder()
      .optionallyWith(
        ids.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.ids)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.codebuild.model.ListBuildsForProjectResponse.ReadOnly =
    zio.aws.codebuild.model.ListBuildsForProjectResponse.wrap(buildAwsValue())
}
object ListBuildsForProjectResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codebuild.model.ListBuildsForProjectResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codebuild.model.ListBuildsForProjectResponse =
      zio.aws.codebuild.model.ListBuildsForProjectResponse(
        ids.map(value => value),
        nextToken.map(value => value)
      )
    def ids: Optional[List[NonEmptyString]]
    def nextToken: Optional[String]
    def getIds: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("ids", ids)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codebuild.model.ListBuildsForProjectResponse
  ) extends zio.aws.codebuild.model.ListBuildsForProjectResponse.ReadOnly {
    override val ids: Optional[List[NonEmptyString]] = zio.aws.core.internal
      .optionalFromNullable(impl.ids())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codebuild.model.primitives.NonEmptyString(item)
        }.toList
      )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.codebuild.model.ListBuildsForProjectResponse
  ): zio.aws.codebuild.model.ListBuildsForProjectResponse.ReadOnly =
    new Wrapper(impl)
}
